LaunchHelper class

Helper for launching URLs, emails, and phone numbers.

Constructors

LaunchHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

email(String email, {String subject = '', String body = ''}) Future<bool>
Launches an email app with the specified email.
phone(String phoneNumber) Future<bool>
Launches the phone dialer.
url(String urlString) Future<bool>
Launches a URL.