PasswordStrength class
A visual indicator for password strength.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PasswordStrength
- Available extensions
Constructors
Properties
- backgroundColor → Color?
-
final
- borderRadius → double
-
final
- fairColor → Color?
-
final
- goodColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minHeight → double
-
final
- password → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strongColor → Color?
-
final
- weakColor → Color?
-
final
Methods
-
animatedRotate(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero, Curve curve = Curves.linear}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Rotates the widget. -
animatedScale(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Scales the widget (similar to zoom but uses a generic ease). -
animateFade(
{bool isVisible = true, Duration duration = const Duration(milliseconds: 300)}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a simple implicit animated opacity. Example:Text('Hello').animateFade(isVisible: true) -
blur(
{double sigmaX = 5.0, double sigmaY = 5.0}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Applies a blur effect over the widget. Example:Image.network(...).blur() -
bounce(
{Duration duration = const Duration(milliseconds: 800), Duration delay = Duration.zero}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Bounces the widget. -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
card(
{double elevation = 1.0, ShapeBorder? shape, EdgeInsetsGeometry? margin}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a Card. Example:Text('Hello').card() -
center(
) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a Center. Example:Text('Hello').center() -
clipRadius(
double radius) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Clips the widget with rounded corners. Example:Image.network(...).clipRadius(10) -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
elastic(
{Duration duration = const Duration(milliseconds: 1000), Duration delay = Duration.zero}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Applies an elastic deformation effect. -
expand(
[int flex = 1]) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in an Expanded. Example:Container().expand() -
fade(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero, Curve curve = Curves.easeIn}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Fades the widget in. -
flip(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero, Curve curve = Curves.easeInOut}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Flips the widget around the Y axis. -
gesture(
{VoidCallback? onTap, VoidCallback? onDoubleTap, VoidCallback? onLongPress}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a generic GestureDetector. Example:Text('Hold Me').gesture(onLongPress: () => print('Held!')) -
gradient(
Gradient gradient) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Applies a shader mask gradient over the widget. Example:Text('Hello').gradient(LinearGradient(...)) -
hero(
Object tag) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a Hero. Example:Image.network(...).hero('image_tag') -
loading(
bool isLoading, {Widget? loader}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Shows a loader instead of the widget ifisLoadingis true. Example:ListView(...).loading(true) -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTap(
VoidCallback? onTap) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a GestureDetector with a simple onTap. Example:Text('Click Me').onTap(() => print('Clicked!')) -
opacity(
double opacity) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Adjusts the opacity of the widget. Example:Text('Hello').opacity(0.5) -
paddingAll(
double value) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a Padding with uniform padding. Example:Text('Hello').paddingAll(16) -
rotate(
{int quarterTurns = 1}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Rotates the widget byquarterTurns. Example:Icon(Icons.arrow_upward).rotate(quarterTurns: 1) -
safeArea(
{bool top = true, bool bottom = true, bool left = true, bool right = true}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a SafeArea. Example:Container().safeArea() -
scale(
double scale) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Scales the widget. Example:Text('Hello').scale(1.5) -
shadow(
{Color color = const Color(0x33000000), double blurRadius = 10.0, Offset offset = Offset.zero, double spreadRadius = 0.0, BorderRadiusGeometry? borderRadius}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Adds a shadow to the widget using a Container and BoxShadow. Example:Container().shadow() -
shake(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Shakes the widget back and forth. -
slide(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero, Curve curve = Curves.easeOut}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Slides the widget in from an offset. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
tooltip(
String message) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Wraps the widget in a Tooltip. Example:Icon(Icons.info).tooltip('Information') -
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
visible(
bool isVisible, {Widget replacement = const SizedBox.shrink()}) → Widget -
Available on Widget, provided by the WidgetExtensions extension
Controls the visibility of the widget. Example:Text('Hello').visible(true) -
wiggle(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Wiggles the widget. -
zoom(
{Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero, Curve curve = Curves.elasticOut}) → Widget -
Available on Widget, provided by the WidgetAnimationExtensions extension
Zooms the widget in (scale from 0 to 1).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited