RandomGenerator class

A utility to generate random data.

Constructors

RandomGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

integer({int min = 0, int max = 100}) int
Generates a random integer between min and max.
string([int length = 10]) String
Generates a random string of the specified length.