utils library

Classes

BatteryHelper
Helper for checking battery status.
ClipboardHelper
Helper for accessing the device clipboard.
Debouncer
A simple debouncer that limits the rate of function execution.
DeviceHelper
Helper for getting device information.
InternetHelper
Helper for checking network connectivity.
LaunchHelper
Helper for launching URLs, emails, and phone numbers.
Logger
A simple logger utility.
PermissionHelper
Helper for requesting and checking permissions.
PlatformHelper
Helper for determining the current platform.
RandomGenerator
A utility to generate random data.
Retry
A utility to easily retry async functions.
StorageHelper
Helper for persistent local storage using Shared Preferences.
Throttle
A simple throttle that ensures a function is called at most once in a specified duration.
UuidGenerator
A UUID generator using the uuid package.